/* Copyright (c) 1994,1997 HD Associates (contact: dufault@hda.com)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 * This product includes software developed by HD Associates
 * 4. Neither the name of the HD Associaates nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY HD ASSOCIATES``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL HD ASSOCIATES OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include "config.h"
#ifndef _I2C_H_
#define _I2C_H_

#include "systypes.h"

/* Timings for the standard I2C bus.  Acronyms are from the data sheet.
 * These are published so that "nano.h" can be optimized for these.
 */

#define I2C_T_buf    4700	/* Bus free time */
#define I2C_T_high   4000	/* SCL HIGH time */
#define I2C_T_low    4700	/* SCL LOW  time */
#define I2C_T_low_2  2350	/* 1/2 SCL LOW  time */
#define I2C_T_hd_sta 4000	/* Start condition hold time */
#define I2C_T_su_dat  250	/* Data set-up time */
#define I2C_T_r      1000	/* SCL and SDA rise time */
#define I2C_T_f       300	/* SCL and SDA fall time */
#define I2C_T_su_sto 4000	/* Stop set-up time */

void i2c_init(void);

int i2c_get_no_ack(u_char *);
int i2c_get(u_char *);

int i2c_put(u_char);
int i2c_start(u_char);
int i2c_stop(void);

ssize_t i2c_write(int, const void *, size_t);
ssize_t i2c_read(int, void *, size_t);

#if defined(I2C_SLAVE)

enum i2cslave_bus_state
{
	I2cbus_free,			/* Bus free */
	I2cbus_start,			/* Start condition */
	I2cbus_get_slave_addr,	/* Getting first byte (slave address) */
	I2cbus_got_slave_addr,	/* Got slave addr, looking for STOP or ACK */
	I2cbus_transfer,		/* Carrying out an I/O transfer */
	I2cbus_transferred,		/* Carried out an I/O transfer */

	I2cbus_none				/* State unknown */
};

enum i2cslave_bus_state i2cslave_poll(int *);
void i2cslave_init(void);
void i2cslave_acknowledge(void);
void i2cslave_send(int data);

#endif /* I2C_SLAVE */

#endif /* _I2C_H_ */
