/*
 * Copyright (C) 1995 HD Associates, Inc.
 * Copyright (C) 1995 Microwave Medical Systems, Inc.
 *
 *  ALL RIGHTS RESERVED.  This is unpublished proprietary source code
 *  of HD Associates, Inc and Microwave Medical Systems.
 *
 * Permission is granted to Microwave Medical Systems to use this source
 * code in the same manner that they use their own proprietary source
 * code.
 *
 * $Id: nano.h,v 3.1 1997/02/06 16:26:29 dufault Exp dufault $
 */
#if !defined(_NANO_H_)
#define _NANO_H_

#if defined(__80196__) || defined(HOST_COMPILE)

/* Accurate enough nano functions for the 16Mhz 80c196.
 *
 * nanotimer_set: Set a nanosecond timer.
 * nanotimer_elapsed: See if the timer has elapsed
 * nanodelay: Delay a given number of nanoseconds.
 */

typedef int nanotimer_t;

/* Scale and offset for the "nanotimer_elapsed" loop:
 */
#define SCALE 1000
#define OFFSET 2000

#define nanotimer_set(N) (((int)((nanotimer_t)((N) / SCALE)) - OFFSET) > 0 ? \
	((int)((nanotimer_t)((N) / SCALE)) - OFFSET) : \
	0)

#define nanotimer_elapsed(NP) ((*(NP))-- <= 0)

/* This may look silly, but the compiler does the right thing.
 */
#define nanodelay(N) do { \
	if (N == 4700) { \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); \
		NANO_DELAY_500(); \
		NANO_DELAY_250(); }  \
	else if (N == 4000) { \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); } \
	else if (N == 2350) { \
		NANO_DELAY_1000(); \
		NANO_DELAY_1000(); \
		NANO_DELAY_250(); }  \
	else if (N == 1000) { \
		NANO_DELAY_1000(); }  \
	else if (N == 300) { \
		NANO_DELAY_250(); }  \
	else if (nanotimer_set(N)) do { \
		nanotimer_t _mk_i = nanotimer_set(N); \
		while (!nanotimer_elapsed(&_mk_i)) \
			; \
	} while (0); \
} while (0)

#else

	#include "systypes.h"

	typedef u_int nanotimer_t;

	nanotimer_t nanotimer_set(u_long);
	int nanotimer_elapsed(nanotimer_t *);
	void nanodelay(u_long);

	/* nanonow is for the debugging display and isn't needed.
	 */
	u_long _nanonow(void);

#endif

#endif /* _NANO_H_ */
